/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */
package org.xwiki.xmlrpc.model;

import java.util.Date;
import java.util.Map;

/**
 * A class representing page history summaries. Modeled after
 * {@link http://confluence.atlassian.com/display/DOC/Remote+API+Specification#RemoteAPISpecification-PageHistorySummary}
 * 
 * @author fmancinelli
 * @category ConfluenceAPI
 */
public class PageHistorySummary extends XmlRpcObject
{
    @XmlRpcObjectField
    protected String id;

    @XmlRpcObjectField
    protected Integer version;

    @XmlRpcObjectField
    protected Integer minorVersion;

    @XmlRpcObjectField
    protected String modifier;

    @XmlRpcObjectField
    protected Date modified;

    /**
     * Default constructor for creating Page objects. Client should not need to use this.
     * 
     * @param id
     * @param version
     * @param minorVersion
     * @param modifier
     * @param modified
     */
    public PageHistorySummary(String id, Integer version, Integer minorVersion, String modifier,
        Date modified)
    {
        super();

        this.id = id;
        this.version = version;
        this.minorVersion = minorVersion;
        this.modifier = modifier;
        this.modified = modified;

        checkFields();
    }

    /**
     * @param map A map containing the associations between XmlRpcObject field names and their
     *            corresponding values.
     * @see XmlRpcObject#XmlRpcObject(Map)
     */
    public PageHistorySummary(Map<String, Object> map)
    {
        super(map);
        checkFields();
    }

    /**
     * Initialize and check that all the fields have correct values.
     */
    private void checkFields()
    {
        if (id == null) {
            throw new IllegalArgumentException("id cannot be null\n");
        }

        if (version == null) {
            throw new IllegalArgumentException("version cannot be null\n");
        }

        if (minorVersion == null) {
            minorVersion = 1;
        }

        if (modifier == null) {
            modifier = "Unknown";
        }

        if (modified == null) {
            throw new IllegalArgumentException("modified cannot be null\n");
        }
    }

    public String getId()
    {
        return id;
    }

    public Integer getVersion()
    {
        return version;
    }

    public Integer getMinorVersion()
    {
        return minorVersion;
    }

    public String getModifier()
    {
        return modifier;
    }

    public Date getModified()
    {
        return modified;
    }
}
