/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */
package org.xwiki.xmlrpc.model;

import java.util.Map;

/**
 * A class representing server info. Modeled after
 * {@link http://confluence.atlassian.com/display/DOC/Remote+API+Specification#RemoteAPISpecification-ServerInfo}
 * 
 * @author fmancinelli
 * @category ConfluenceAPI
 */
public class ServerInfo extends XmlRpcObject
{
    @XmlRpcObjectField
    protected Integer majorVersion;

    @XmlRpcObjectField
    protected Integer minorVersion;

    @XmlRpcObjectField
    protected Integer patchLevel;

    @XmlRpcObjectField
    protected String buildId;

    @XmlRpcObjectField
    protected Boolean developmentBuild;

    @XmlRpcObjectField
    protected String baseUrl;

    /**
     * Default constructor for creating ServerInfo objects. Client should not need to use this.
     * 
     * @param majorVersion
     * @param minorVersion
     * @param patchLevel
     * @param buildId
     * @param developmentBuild
     * @param baseUrl
     */
    public ServerInfo(Integer majorVersion, Integer minorVersion, Integer patchLevel,
        String buildId, Boolean developmentBuild, String baseUrl)
    {
        super();

        this.majorVersion = majorVersion;
        this.minorVersion = minorVersion;
        this.patchLevel = patchLevel;
        this.buildId = buildId;
        this.developmentBuild = developmentBuild;
        this.baseUrl = baseUrl;

        checkFields();
    }

    /**
     * @param map A map containing the associations between XmlRpcObject field names and their
     *            corresponding values.
     * @see XmlRpcObject#XmlRpcObject(Map)
     */
    public ServerInfo(Map<String, Object> map)
    {
        super(map);
        checkFields();
    }

    /**
     * Initialize and check that all the fields have correct values.
     */
    private void checkFields()
    {
        if (majorVersion == null) {
            majorVersion = 0;
        }

        if (minorVersion == null) {
            minorVersion = 0;
        }

        if (patchLevel == null) {
            patchLevel = 0;
        }

        if (buildId == null) {
            buildId = "No build id";
        }

        if (developmentBuild == null) {
            developmentBuild = false;
        }

        if (baseUrl == null) {
            baseUrl = "No base url";
        }
    }

    public Integer getMajorVersion()
    {
        return majorVersion;
    }

    public Integer getMinorVersion()
    {
        return minorVersion;
    }

    public Integer getPatchLevel()
    {
        return patchLevel;
    }

    public String getBuildId()
    {
        return buildId;
    }

    public Boolean getDevelopmentBuild()
    {
        return developmentBuild;
    }

    public String getBaseUrl()
    {
        return baseUrl;
    }
}
