/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */
package org.xwiki.xmlrpc.model;

import java.util.Map;

/**
 * A class representing space summaries. Modeled after
 * {@link http://confluence.atlassian.com/display/DOC/Remote+API+Specification#RemoteAPISpecification-PageSummary}
 * 
 * @author fmancinelli
 * @category ConfluenceAPI
 */
public class SpaceSummary extends XmlRpcObject
{
    @XmlRpcObjectField
    protected String key;

    @XmlRpcObjectField
    protected String name;

    @XmlRpcObjectField
    protected String type;

    @XmlRpcObjectField
    protected String url;

    /**
     * Default constructor for creating SpaceSummary objects. Client should not need to use this.
     * 
     * @param key
     * @param name
     * @param type
     * @param url
     */
    public SpaceSummary(String key, String name, String type, String url)
    {
        super();

        this.key = key;
        this.name = name;
        this.type = type;
        this.url = url;

        checkFields();
    }

    /**
     * @param map A map containing the associations between XmlRpcObject field names and their
     *            corresponding values.
     * @see XmlRpcObject#XmlRpcObject(Map)
     */
    public SpaceSummary(Map<String, Object> map)
    {
        super(map);
        checkFields();
    }

    /**
     * Initialize and check that all the fields have correct values.
     */
    private void checkFields()
    {
        if (key == null) {
            throw new IllegalArgumentException("Page key is not specified\n");
        }

        if (name == null) {
            name = key;
        }

        if (type == null) {
            type = "No type";
        }

        if (url == null) {
            url = "";
        }
    }

    public String getKey()
    {
        return key;
    }

    public String getName()
    {
        return name;
    }

    public String getType()
    {
        return type;
    }

    public String getUrl()
    {
        return url;
    }
}
