/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */
package org.xwiki.xmlrpc.model;

import java.util.Map;

/**
 * A class representing XWiki class summaries.
 * 
 * @author fmancinelli
 * @category XWikiSpecific
 */
public class XWikiClassSummary extends XmlRpcObject
{
    @XmlRpcObjectField
    protected String id;

    /**
     * Default constructor for creating XWikiClassSummary objects. Client should not need to use
     * this.
     * 
     * @param id
     */
    public XWikiClassSummary(String id)
    {
        this.id = id;
        checkFields();
    }

    /**
     * @param map A map containing the associations between XmlRpcObject field names and their
     *            corresponding values.
     * @see XmlRpcObject#XmlRpcObject(Map)
     */
    public XWikiClassSummary(Map<String, Object> map)
    {
        super(map);
        checkFields();
    }

    /**
     * Initialize and check that all the fields have correct values.
     */
    private void checkFields()
    {
        if (id == null) {
            throw new IllegalArgumentException("id must not be null");
        }
    }

    public String getId()
    {
        return id;
    }
}
