/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */
package org.xwiki.xmlrpc.model;

import java.util.Map;

/**
 * A class representing XWiki object summaries.
 * 
 * @author fmancinelli
 * @category XWikiSpecific
 */
public class XWikiObjectSummary extends XmlRpcObject
{
    @XmlRpcObjectField
    protected String pageId;

    @XmlRpcObjectField
    protected String className;

    @XmlRpcObjectField
    protected Integer id;

    @XmlRpcObjectField
    protected String prettyName;

    /**
     * Default constructor for creating XWikiClassSummary objects. Client should not need to use
     * this.
     * 
     * @param pageId
     * @param className
     * @param id
     * @param prettyName
     */
    public XWikiObjectSummary(String pageId, String className, Integer id, String prettyName)
    {
        this.pageId = pageId;
        this.className = className;
        this.id = id;
        this.prettyName = prettyName;

        checkFields();
    }

    /**
     * @param map A map containing the associations between XmlRpcObject field names and their
     *            corresponding values.
     * @see XmlRpcObject#XmlRpcObject(Map)
     */
    public XWikiObjectSummary(Map<String, Object> map)
    {
        super(map);
        checkFields();
    }

    /**
     * Initialize and check that all the fields have correct values.
     */
    private void checkFields()
    {
        if (pageId == null) {
            throw new IllegalArgumentException("pageId cannot be null.");
        }

        if (className == null) {
            throw new IllegalArgumentException("className cannot be null.");
        }

        if (id == null) {
            throw new IllegalArgumentException("id cannot be null.");
        }

        if (prettyName == null) {
            prettyName = String.format("%s[%d]", pageId, id);
        }
    }

    public String getPageId()
    {
        return pageId;
    }

    public String getClassName()
    {
        return className;
    }

    public Integer getId()
    {
        return id;
    }

    public String getPrettyName()
    {
        return prettyName;
    }
}
