/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */
package org.xwiki.xmlrpc.model;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.junit.Assert;
import org.junit.Test;

class BadXmlRpcObjectSubClass extends XmlRpcObject
{
    @XmlRpcObjectField
    protected Integer integerField;

    @XmlRpcObjectField
    protected Long longField;
}

class GoodXmlRpcObjectSubClass extends XmlRpcObject
{
    @XmlRpcObjectField
    protected Boolean booleanField;

    @XmlRpcObjectField
    protected Integer integerField;

    @XmlRpcObjectField
    protected Double doubleField;

    @XmlRpcObjectField
    protected Date dateField;

    @XmlRpcObjectField
    protected List listField;

    @XmlRpcObjectField
    protected Map mapField;

    @XmlRpcObjectField
    private Integer privateIntegerField;

    public GoodXmlRpcObjectSubClass()
    {
        super();
    }

    public GoodXmlRpcObjectSubClass(Map<String, Object> fieldToValueMap)
    {
        super(fieldToValueMap);
    }
}

public class XmlRpcObjectTest
{
    @Test(expected = RuntimeException.class)
    public void testBadXmlRpcObjectSubclass()
    {
        BadXmlRpcObjectSubClass object = new BadXmlRpcObjectSubClass();
    }

    @Test
    public void testGoodXmlRpcObjectSubclass()
    {
        GoodXmlRpcObjectSubClass object = new GoodXmlRpcObjectSubClass();
    }

    @Test
    public void testMapInitialization()
    {
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("integerField", new Integer(10));
        map.put("doubleField", new Double(20.0));
        map.put("dateField", new Date());
        map.put("listField", new ArrayList());
        map.put("mapField", new HashMap());

        GoodXmlRpcObjectSubClass object = new GoodXmlRpcObjectSubClass(map);
    }

    @Test(expected = IllegalArgumentException.class)
    public void testBadMapInitializationOnInteger()
    {
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("integerField", new Double(10));
        GoodXmlRpcObjectSubClass object = new GoodXmlRpcObjectSubClass(map);
    }

    @Test(expected = RuntimeException.class)
    public void testMapInitializationOnPrivateField()
    {
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("privateIntegerField", new Integer(10));
        GoodXmlRpcObjectSubClass object = new GoodXmlRpcObjectSubClass(map);
    }

    @Test
    public void testStringInitialization()
    {
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("booleanField", "true");
        map.put("integerField", "10");
        map.put("doubleField", "10.2");
        GoodXmlRpcObjectSubClass object = new GoodXmlRpcObjectSubClass(map);

        Assert.assertEquals(object.booleanField, new Boolean(true));
        Assert.assertEquals(object.integerField, new Integer(10));
        Assert.assertEquals(object.doubleField, new Double(10.2));
    }

}
